Welcome to Pty-chi's documentation!
====================================

.. image:: img/logo.png
   :alt: Pty-chi Logo
   :align: center
   :width: 200px

Pty-chi is a PyTorch-based ptychography reconstruction library.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   using_pty_chi/index
   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search` 